@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 2.14.x SVN: $Id$
+ * @version    Release 2.15.x SVN: $Id$
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -45,6 +45,7 @@ define('M3_SYSTEM_DEBUG_OUT', true);			// デバッグ文出力を行うかど
 define('M3_SYSTEM_REALTIME_ANALYTICS', false);	// 即時アクセス解析を行うかどうか
 
 // ######### 別名定義 #########
+define('M3_DS',	'/');				// ディレクトリセパレータ
 define('M3_NL',	"\n");				// 改行
 define('M3_TB',	"\t");				// タブ
 define('M3_INDENT_SPACE', '    ');	// 字下げスペース
@@ -55,8 +56,8 @@ define('M3_TITLE_BRACKET_END',		'」');					// タイトルを括弧表記する
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'2.14.4');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2015/10/22');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'2.15.0');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2015/11/17');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -102,6 +103,7 @@ define('M3_TAG_MACRO_ITEM_KEY',		'ITEM_KEY_');							// 汎用置換キー
 define('M3_TAG_MACRO_CONTENT_KEY',	'CT_');									// コンテンツマクロ置換キー
 define('M3_TAG_MACRO_COMMENT_KEY',	'CM_');									// コメントマクロ置換キー
 define('M3_TAG_MACRO_USER_KEY',		'USER_');								// ユーザ定義置換キー
+define('M3_TAG_MACRO_DEFAULT',		'DEFAULT');								// システムデフォルト値に置換
 define('M3_TAG_MACRO_ITEM',			'ITEM');								// 項目置換キー
 define('M3_TAG_MACRO_TITLE',		'TITLE');								// タイトル置換キー
 define('M3_TAG_MACRO_NOTITLE',		'NOTITLE');								// タイトル置換キー(タイトルなしの場合)
