@@ -8,16 +8,15 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainBaseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainServeradminBaseWidgetContainer.php');
 
-class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
+class admin_mainSitelistWidgetContainer extends admin_mainServeradminBaseWidgetContainer
 {
-	private $cmdPath;		// ジョブ格納ディレクトリ
 	const HOME_DIR = '/home';
 	const SITE_DEF_FILE = '/public_html/include/siteDef.php';
 	const GLOBAL_FILE = '/public_html/include/global.php';
@@ -27,9 +26,7 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 	const ACTIVE_ICON_FILE = '/images/system/active32.png';			// 運用中アイコン
 	const NOT_INSTALLED_ICON_FILE = '/images/system/notice32.png';			// インストール未実行アイコン
 	const WINDOW_ICON_FILE = '/images/system/window32.png';			// 管理画面アイコン
-	const CMD_FILENAME_CREATE_SITE = 'CMD_00_CREATESITE';			// サイト作成ジョブファイル名
-	const CMD_FILENAME_REMOVE_SITE = 'CMD_00_REMOVESITE';			// サイト削除ジョブファイル名
-	const CMD_FILENAME_UPDATE_INSTALL_PACKAGE = 'CMD_00_UPDATEINSTALLPACKAGE';			// インストールパッケージ取得ジョブファイル名
+	const MAX_SITE_COUNT = 3;		// 管理サイト最大数
 	
 	/**
 	 * コンストラクタ
@@ -38,10 +35,6 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 	{
 		// 親クラスを呼び出す
 		parent::__construct();
-		
-		// ジョブ格納ディレクトリ
-		$this->cmdPath = $this->gEnv->getCronjobsPath();
-		if (!file_exists($this->cmdPath)) mkdir($this->cmdPath, M3_SYSTEM_DIR_PERMISSION, true/*再帰的*/);
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -102,7 +95,7 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 		$masterHostId = basename(dirname($this->gEnv->getSystemRootPath()));
 		
 		// ジョブの実行状況を表示
-		$isShownJobStatus = $this->_showJobStatus();
+//		$isShownJobStatus = $this->_showJobStatus();
 		
 		// ディレクトリ一覧を取得
 		$hostArray = array();
@@ -110,7 +103,7 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 		if ($ret = @is_dir($searchPath)){
 			$dir = dir($searchPath);
 			while (($file = $dir->read()) !== false){
-				$filePath = $searchPath . DIRECTORY_SEPARATOR . $file;
+				$filePath = $searchPath . M3_DS . $file;
 				$pathParts = pathinfo($file);
 					
 				// ディレクトリのときは、ドメイン名を取得
@@ -173,9 +166,9 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 			$titleStr = self::LINK_ADMIN_PAGE;
 			$iconUrl = $this->gEnv->getRootUrl() . self::WINDOW_ICON_FILE;		// 管理画面アイコン
 			if ($isSslAdminUrl){		// マスターホストの管理画面がSSLでのアクセスの場合は、管理対象のホストの管理画面もSSLアクセスとする
-				$linkUrl = 'https://' . $line['hostname'] . '/' . M3_DIR_NAME_ADMIN . '/';
+				$linkUrl = 'https://' . $line['hostname'] . M3_DS . M3_DIR_NAME_ADMIN . M3_DS;
 			} else {
-				$linkUrl = 'http://' . $line['hostname'] . '/' . M3_DIR_NAME_ADMIN . '/';
+				$linkUrl = 'http://' . $line['hostname'] . M3_DS . M3_DIR_NAME_ADMIN . M3_DS;
 			}
 			$linkTag = '<a href="' . convertUrlToHtmlEntity($linkUrl) . '" target="_blank" rel="m3help" title="' . $titleStr . '">';
 			$linkTag .= '<img src="' . $this->getUrl($iconUrl) . '" alt="' . $titleStr . '" /></a>';
@@ -186,13 +179,16 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 				'host'		=> $hostStr,	// ホスト名
 				'status'	=> $statusTag,	// 状態
 				'dir'		=> $this->convertToDispString($line['dir']),			// ディレクトリ名
-				'date'		=> $this->convertToDispDate(date("Y/m/d H:i:s", $line['date'])),			// 作成日時
+				'date'		=> $this->convertToDispDateTime(date("Y/m/d H:i:s", $line['date']), 0/*ロングフォーマット*/, 10/*時分*/),			// 作成日時
 				'disksize'	=> $this->convertToDispString(convFromBytes($line['disksize'])),			// ディスク使用量
 				'link'		=> $linkTag
 			);
 			$this->tmpl->addVars('sitelist', $row);
 			$this->tmpl->parseTemplate('sitelist', 'a');
 		}
+		
+		// 管理可能なホスト数の上限を超えている場合は新規ボタンを使用不可にする
+		if (count($hostArray) >= self::MAX_SITE_COUNT) $this->tmpl->addVar('_widget', 'add_button_disabled', $this->convertToDisabledString(1));
 	}
 	/**
 	 * 詳細画面作成
@@ -210,14 +206,16 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 		$vhostList = $this->_getVirtualHostInfo();
 
 		// ジョブ実行ファイル
-		$cmdFile_create_site = $this->cmdPath . DIRECTORY_SEPARATOR . self::CMD_FILENAME_CREATE_SITE;		// サイト作成、コマンドファイル
-		$cmdFile_remove_site = $this->cmdPath . DIRECTORY_SEPARATOR . self::CMD_FILENAME_REMOVE_SITE;		// サイト削除、コマンドファイル
+//		$cmdFile_create_site = $this->cmdPath . M3_DS . self::CMD_FILENAME_CREATE_SITE;		// サイト作成、コマンドファイル
+//		$cmdFile_remove_site = $this->cmdPath . M3_DS . self::CMD_FILENAME_REMOVE_SITE;		// サイト削除、コマンドファイル
 		
 		// ジョブの実行状況を表示
-		$isShownJobStatus = $this->_showJobStatus();
+//		$isShownJobStatus = $this->_showJobStatus();
 		
 		$reloadData = false;		// データを再取得するかどうか
 		if ($act == 'add'){		// 新規追加のとき
+			if (count($vhostList) > self::MAX_SITE_COUNT) $this->setUserErrorMsg('管理可能なホスト数を超えています');
+			
 			// 入力チェック
 			$ret = $this->checkInput($hostname, 'ホスト名');		// ホスト名
 			if ($ret && !preg_match('/^(?:[-A-Za-z0-9]+\.)+[A-Za-z]{2,6}$/', $hostname)) $this->setUserErrorMsg('不正なホスト名です');
@@ -239,7 +237,7 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 				$email = $this->gEnv->getSiteEmail();
 				if (!empty($email)) $cmdContent .= 'mailto=' . $email . "\n";
 				$cmdContent .= 'hostname=' . $hostname . "\n";
-				$ret = file_put_contents($cmdFile_create_site, $cmdContent, LOCK_EX/*排他的アクセス*/);
+				$ret = file_put_contents($this->cmdFile_create_site, $cmdContent, LOCK_EX/*排他的アクセス*/);
 				if ($ret !== false){
 					$id = $hostname;
 					$reloadData = true;			// データを再取得
@@ -261,7 +259,7 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 				$email = $this->gEnv->getSiteEmail();
 				if (!empty($email)) $cmdContent .= 'mailto=' . $email . "\n";
 				$cmdContent .= 'hostname=' . $id . "\n";
-				$ret = file_put_contents($cmdFile_remove_site, $cmdContent, LOCK_EX/*排他的アクセス*/);
+				$ret = file_put_contents($this->cmdFile_remove_site, $cmdContent, LOCK_EX/*排他的アクセス*/);
 				if ($ret !== false){
 					$reloadData = true;			// データを再取得
 
@@ -274,9 +272,9 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 		} else if ($act == 'getinfo'){		// 最新情報取得
 			$type = $request->trimValueOf('type');			// 実行コマンドタイプ
 			if ($type == 'create_site'){
-				$cmdFile = $cmdFile_create_site;		// サイト作成、コマンドファイル
+				$cmdFile = $this->cmdFile_create_site;		// サイト作成、コマンドファイル
 			} else if ($type == 'remove_site'){
-				$cmdFile = $cmdFile_remove_site;		// サイト削除、コマンドファイル
+				$cmdFile = $this->cmdFile_remove_site;		// サイト削除、コマンドファイル
 			}
 			if (file_exists($cmdFile)){
 				$this->gInstance->getAjaxManager()->addData('code', '0');
@@ -300,7 +298,7 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 			}
 			if (!empty($hostId)){
 				// ディレクトリ日付取得
-				$siteDir = self::HOME_DIR . DIRECTORY_SEPARATOR . $hostId;
+				$siteDir = self::HOME_DIR . M3_DS . $hostId;
 				if (file_exists($siteDir)){
 					$createDt = date("Y/m/d H:i:s", filemtime($siteDir));
 				
@@ -321,17 +319,17 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 			$this->tmpl->addVar("input_hostname", "hostname", $this->convertToDispString($hostname));			// ホスト名
 			
 			// ジョブメッセージが表示されているときはボタン使用不可
-			$this->tmpl->addVar("add_button", "add_button_disabled", $this->convertToDisabledString($isShownJobStatus));
+			$this->tmpl->addVar("add_button", "add_button_disabled", $this->convertToDisabledString($this->isShownJobStatus));
 		} else {
 			$this->tmpl->setAttribute('update_button', 'visibility', 'visible');// 削除ボタン表示
 			$this->tmpl->addVar("_widget", "hostname", $this->convertToDispString($hostname));			// ホスト名
 			
 			// ジョブメッセージが表示されているときはボタン使用不可
-			$this->tmpl->addVar("update_button", "del_button_disabled", $this->convertToDisabledString($isShownJobStatus));
+			$this->tmpl->addVar("update_button", "del_button_disabled", $this->convertToDisabledString($this->isShownJobStatus));
 		}
 		$this->tmpl->addVar("_widget", "id", $this->convertToDispString($id));		// ID(ホスト名)
 		$this->tmpl->addVar("_widget", "host_id", $this->convertToDispString($hostId));		// ホストID
-		$this->tmpl->addVar("_widget", "date", $this->convertToDispDate($createDt));		// 作成日付
+		$this->tmpl->addVar("_widget", "date", $this->convertToDispDateTime($createDt, 0/*ロングフォーマット*/, 10/*時分*/));		// 作成日付
 		$this->tmpl->addVar("_widget", "version", $this->convertToDispString($version));		// Magic3バージョン
 		$this->tmpl->addVar("_widget", "msg_completed", $msgCompleted);		// 処理完了メッセージ
 		$this->tmpl->addVar("_widget", "msg_error", $msgError);		// 処理エラーメッセージ
@@ -361,32 +359,5 @@ class admin_mainSitelistWidgetContainer extends admin_mainBaseWidgetContainer
 		
 		return $vhostList;
 	}
-	/**
-	 * ジョブの実行状況を表示
-	 *
-	 * @return bool			メッセージ表示ありかどうか
-	 */
-	function _showJobStatus()
-	{
-		$isShown = false;
-		
-		// ジョブの実行状況を表示
-		$cmdFile_create_site = $this->cmdPath . DIRECTORY_SEPARATOR . self::CMD_FILENAME_CREATE_SITE;		// サイト作成、コマンド実行ファイル
-		$cmdFile_remove_site = $this->cmdPath . DIRECTORY_SEPARATOR . self::CMD_FILENAME_REMOVE_SITE;		// サイト削除、コマンド実行ファイル
-		$cmdFile_update_insatll_package = $this->cmdPath . DIRECTORY_SEPARATOR . self::CMD_FILENAME_UPDATE_INSTALL_PACKAGE;			// インストールパッケージ取得ジョブファイル名
-		if (file_exists($cmdFile_create_site)){
-			$this->setUserErrorMsg('サイトの作成中です');
-			$isShown = true;			// メッセージ表示あり
-		}
-		if (file_exists($cmdFile_remove_site)){
-			$this->setUserErrorMsg('サイトの削除中です');
-			$isShown = true;			// メッセージ表示あり
-		}
-		if (file_exists($cmdFile_update_insatll_package)){
-			$this->setUserErrorMsg('インストーラの更新中です');
-			$isShown = true;			// メッセージ表示あり
-		}
-		return $isShown;
-	}
 }
 ?>
