@@ -13,6 +13,13 @@
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
+/***************************************************************************************************
+### 複製元クラス admin_blog_mainEntryWidgetContainer ###
+複製元クラスからblog_mainEntryWidgetContainerクラスを生成する
+変更行
+　・親クラスファイルの読み込み(require_once)
+　・クラス名定義
+****************************************************************************************************/
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_blog_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/blog_mainDb.php');
 require_once($gEnvManager->getCommonPath() . '/valueCheck.php');
@@ -25,13 +32,15 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 	private $langId;		// 現在の選択言語
 	private $serialArray = array();		// 表示されている項目シリアル番号
 	private $categoryListData;		// 全記事カテゴリー
+	private $categorySortInfo;		// カテゴリーソート情報
 	private $categoryArray;			// 選択中の記事カテゴリー
 	private $categoryCount;			// カテゴリ数
 	private $isMultiLang;			// 多言語対応画面かどうか
+	private $useMultiBlog;// マルチブログを使用するかどうか
+	private $useComment;// コメント機能を使用するかどうか
 	private $fieldValueArray;		// ユーザ定義フィールド入力値
 	const ICON_SIZE = 32;		// アイコンのサイズ
 	const EYECATCH_IMAGE_SIZE = 40;		// アイキャッチ画像サイズ
-	const CONTENT_TYPE = 'bg';		// 記事参照数取得用
 	const DEFAULT_LIST_COUNT = 20;			// 最大リスト表示数
 	const LINK_PAGE_COUNT		= 20;			// リンクページ数
 	const CATEGORY_NAME_SIZE = 20;			// カテゴリー名の最大文字列長
@@ -39,8 +48,8 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 	const ACTIVE_ICON_FILE = '/images/system/active32.png';			// 公開中アイコン
 	const INACTIVE_ICON_FILE = '/images/system/inactive32.png';		// 非公開アイコン
 	const SEARCH_ICON_FILE = '/images/system/search16.png';		// 検索用アイコン
-	const NO_BLOG_NAME = '所属なし';		// 所属ブログなし
 	const FIELD_HEAD = 'item_';			// フィールド名の先頭文字列
+	const NO_BLOG_NAME = '所属なし';		// 所属ブログなし
 	const TAG_ID_ACTIVE_TERM = 'activeterm_button';		// 公開期間エリア表示用ボタンタグ
 	const TOOLTIP_ACTIVE_TERM = '公開期間を設定';		// 公開期間エリア表示用ボタンツールチップ
 	
@@ -51,8 +60,28 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 	{
 		// 親クラスを呼び出す
 		parent::__construct();
-		
+	}
+	/**
+	 * ウィジェット初期化
+	 *
+	 * 共通パラメータの初期化や、以下のパターンでウィジェット出力方法の変更を行う。
+	 * ・組み込みの_setTemplate(),_assign()を使用
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @return 								なし
+	 */
+	function _init($request)
+	{
+		// 初期値取得
 		$this->isMultiLang = $this->gEnv->isMultiLanguageSite();			// 多言語対応画面かどうか
+		
+		// DB定義値取得
+		$this->useMultiBlog		= self::$_configArray[blog_mainCommonDef::CF_USE_MULTI_BLOG];// マルチブログを使用するかどうか
+		$this->useComment		= self::$_configArray[blog_mainCommonDef::CF_RECEIVE_COMMENT];// コメント機能を使用するかどうか
+		$this->categoryCount	= self::$_configArray[blog_mainCommonDef::CF_CATEGORY_COUNT];			// カテゴリ数
+		if (empty($this->categoryCount)) $this->categoryCount = blog_mainCommonDef::DEFAULT_CATEGORY_COUNT;
+		
+		self::$_mainDb->getAllCategory($this->_langId, $this->categoryListData);		// カテゴリー情報
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -134,12 +163,9 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 	 */
 	function createList($request)
 	{
-		// 初期値取得
-		$defaultLangId = $this->gEnv->getDefaultLanguage();
-		
 		$act = $request->trimValueOf('act');
 		$this->langId = $request->trimValueOf('item_lang');				// 現在メニューで選択中の言語
-		if (empty($this->langId)) $this->langId = $defaultLangId;			// 言語が選択されていないときは、デフォルト言語を設定
+		if (empty($this->langId)) $this->langId = $this->gEnv->getDefaultLanguage();			// 言語が選択されていないときは、デフォルト言語を設定
 		if ($this->gEnv->isAdminDirAccess()){		// 管理画面へのアクセスの場合
 			$this->blogId = null;	// デフォルトブログ(ブログID空)を含むすべてのブログ記事にアクセス可能
 		} else {
@@ -151,7 +177,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		
 		// DBの保存設定値を取得
 		$maxListCount = self::DEFAULT_LIST_COUNT;
-		$serializedParam = $this->_db->getWidgetParam($this->gEnv->getCurrentWidgetId());
+		$serializedParam = $this->_db->getWidgetParam($this->_widgetId);
 		if (!empty($serializedParam)){
 			$dispInfo = unserialize($serializedParam);
 			$maxListCount = $dispInfo->maxMemberListCountByAdmin;		// 会員リスト最大表示数
@@ -210,7 +236,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 							//$this->gInstance->getImageManager()->delSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $oldFiles);
 							
 							// アイキャッチ画像削除
-							blog_mainCommonDef::removerEyecatchImage($infoObj->entryId);
+							blog_mainCommonDef::removeEyecatchImage($infoObj->entryId);
 						}
 					}
 
@@ -225,7 +251,6 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					// 運用ログを残す
 					for ($i = 0; $i < count($delEntryInfo); $i++){
 						$infoObj = $delEntryInfo[$i];
-						//$this->gOpeLog->writeUserInfo(__METHOD__, 'ブログ記事を削除しました。タイトル: ' . $infoObj->name, 2100, 'ID=' . $infoObj->entryId);
 						$eventParam = array(	M3_EVENT_HOOK_PARAM_CONTENT_TYPE	=> M3_VIEW_TYPE_BLOG,
 												M3_EVENT_HOOK_PARAM_CONTENT_ID		=> $infoObj->entryId,
 												M3_EVENT_HOOK_PARAM_UPDATE_DT		=> date("Y/m/d H:i:s"));
@@ -259,7 +284,6 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		if (count($this->serialArray) <= 0) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');// 投稿記事がないときは、一覧を表示しない
 		
 		// カテゴリーメニューを作成
-		self::$_mainDb->getAllCategory($this->langId, $this->categoryListData);
 		$this->createCategoryMenu(1);		// メニューは１つだけ表示
 		
 		// プレビュー用URL
@@ -290,17 +314,6 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 	 */
 	function createDetail($request)
 	{
-		// デフォルト値
-		$defaultLangId	= $this->gEnv->getDefaultLanguage();
-		$regUserId		= $this->gEnv->getCurrentUserId();			// 記事投稿ユーザ
-		//$regDt			= date("Y/m/d H:i:s");						// 投稿日時
-		
-		// ブログ定義値
-		$useMultiBlog = self::$_configArray[blog_mainCommonDef::CF_USE_MULTI_BLOG];// マルチブログを使用するかどうか
-		$useComment = self::$_configArray[blog_mainCommonDef::CF_RECEIVE_COMMENT];// コメント機能を使用するかどうか
-		$this->categoryCount = self::$_configArray[blog_mainCommonDef::CF_CATEGORY_COUNT];			// カテゴリ数
-		if (empty($this->categoryCount)) $this->categoryCount = self::DEFAULT_CATEGORY_COUNT;
-		
 		// コンテンツレイアウトを取得
 		$contentLayout = array(self::$_configArray[blog_mainCommonDef::CF_LAYOUT_ENTRY_SINGLE], self::$_configArray[blog_mainCommonDef::CF_LAYOUT_ENTRY_LIST]);
 		$fieldInfoArray = blog_mainCommonDef::parseUserMacro($contentLayout);
@@ -309,10 +322,9 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		$openBy = $request->trimValueOf(M3_REQUEST_PARAM_OPEN_BY);		// ウィンドウオープンタイプ
 		$act = $request->trimValueOf('act');
 		$this->langId = $request->trimValueOf('item_lang');				// 現在メニューで選択中の言語
-		if (empty($this->langId)) $this->langId = $defaultLangId;			// 言語が選択されていないときは、デフォルト言語を設定	
+		if (empty($this->langId)) $this->langId = $this->gEnv->getDefaultLanguage();			// 言語が選択されていないときは、デフォルト言語を設定	
 		$this->entryId = $request->trimValueOf('entryid');		// 記事エントリーID
 		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
-//		if (empty($this->serialNo)) $this->serialNo = 0;
 		$this->blogId = $request->trimValueOf(M3_REQUEST_PARAM_BLOG_ID);		// 所属ブログ
 		$name = $request->trimValueOf('item_name');
 		$entry_date = $request->trimValueOf('item_entry_date');		// 投稿日
@@ -328,7 +340,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		$showComment = ($request->trimValueOf('show_comment') == 'on') ? 1 : 0;				// コメントを表示するかどうか
 		$receiveComment = ($request->trimValueOf('receive_comment') == 'on') ? 1 : 0;		// コメントを受け付けるかどうか
 		$relatedContent = $request->trimValueOf('item_related_content');	// 関連コンテンツ
-		if (!$useComment){		// コメント機能を使用しない場合のデフォルト値
+		if (!$this->useComment){		// コメント機能を使用しない場合のデフォルト値
 			$showComment = 1;				// コメントを表示するかどうか
 			$receiveComment = 1;		// コメントを受け付けるかどうか
 		}
@@ -342,6 +354,8 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 				$this->categoryArray[] = $itemValue;
 			}
 		}
+		// カテゴリーをソート
+		$this->sortCategory($this->categoryArray);
 
 		// 公開期間を取得
 		$start_date = $request->trimValueOf('item_start_date');		// 公開期間開始日付
@@ -448,13 +462,14 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 										'be_thumb_filename'		=> $thumbFilename,		// サムネールファイル名
 										'be_related_content'	=> $relatedContent,		// 関連コンテンツ
 										'be_option_fields'		=> $this->serializeArray($this->fieldValueArray));				// ユーザ定義フィールド値
-				//if ($act == 'add'){
+
+				// 記事データを追加
 				if (($this->isMultiLang && $this->langId == $this->gEnv->getDefaultLanguage()) || !$this->isMultiLang){		// 多言語でデフォルト言語、または単一言語のとき
 					$ret = self::$_mainDb->addEntryItem($nextEntryId * (-1)/*次のコンテンツIDのチェック*/, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
-													$regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial, $otherParams);
+													$this->_userId, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial, $otherParams);
 				} else {
 					$ret = self::$_mainDb->addEntryItem($this->entryId, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
-													$regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial, $otherParams);
+													$this->_userId, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial, $otherParams);
 				}
 				if ($ret){
 					$this->setGuidanceMsg('データを追加しました');
@@ -499,7 +514,6 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 							case 3:	$statusStr = '非公開';	break;
 						}
 					}
-					//$this->gOpeLog->writeUserInfo(__METHOD__, 'ブログ記事を追加(' . $statusStr . ')しました。タイトル: ' . $name, 2100, 'ID=' . $this->entryId);
 					$eventParam = array(	M3_EVENT_HOOK_PARAM_CONTENT_TYPE	=> M3_VIEW_TYPE_BLOG,
 											M3_EVENT_HOOK_PARAM_CONTENT_ID		=> $this->entryId,
 											M3_EVENT_HOOK_PARAM_UPDATE_DT		=> $updateDt);
@@ -561,7 +575,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 						}
 					} else {		// 記事非公開の場合
 						// 公開ディレクトリのアイキャッチ画像を削除
-						blog_mainCommonDef::removerEyecatchImageInPublicDir($this->entryId);
+						blog_mainCommonDef::removeEyecatchImageInPublicDir($this->entryId);
 					}
 				}
 
@@ -579,6 +593,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					// ### 履歴データを再取得すべき? ###
 				}
 			
+				// 記事データを更新
 				$ret = self::$_mainDb->updateEntryItem($this->serialNo, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
 													''/*投稿者そのまま*/, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial, $oldRecord, $otherParams);
 /*				if ($ret){
@@ -632,7 +647,6 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 							case 3:	$statusStr = '非公開';	break;
 						}
 					}
-					//$this->gOpeLog->writeUserInfo(__METHOD__, 'ブログ記事を更新(' . $statusStr . ')しました。タイトル: ' . $name, 2100, 'ID=' . $this->entryId);
 					$eventParam = array(	M3_EVENT_HOOK_PARAM_CONTENT_TYPE	=> M3_VIEW_TYPE_BLOG,
 											M3_EVENT_HOOK_PARAM_CONTENT_ID		=> $this->entryId,
 											M3_EVENT_HOOK_PARAM_UPDATE_DT		=> $updateDt);
@@ -667,7 +681,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 //						$this->gInstance->getImageManager()->delSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $oldFiles);
 						
 						// アイキャッチ画像削除
-						blog_mainCommonDef::removerEyecatchImage($this->entryId);
+						blog_mainCommonDef::removeEyecatchImage($this->entryId);
 					}
 						
 					// キャッシュデータのクリア
@@ -677,7 +691,6 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					$this->gPage->updateParentWindow();
 					
 					// 運用ログを残す
-					//$this->gOpeLog->writeUserInfo(__METHOD__, 'ブログ記事を削除しました。タイトル: ' . $name, 2100, 'ID=' . $this->entryId);
 					$eventParam = array(	M3_EVENT_HOOK_PARAM_CONTENT_TYPE	=> M3_VIEW_TYPE_BLOG,
 											M3_EVENT_HOOK_PARAM_CONTENT_ID		=> $this->entryId,
 											M3_EVENT_HOOK_PARAM_UPDATE_DT		=> date("Y/m/d H:i:s"));
@@ -707,7 +720,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 //					$ret = blog_mainCommonDef::removeThumbnail($this->entryId);
 					
 					// アイキャッチ画像削除
-					blog_mainCommonDef::removerEyecatchImage($this->entryId);
+					blog_mainCommonDef::removeEyecatchImage($this->entryId);
 						
 					// キャッシュデータのクリア
 					$this->clearCacheBySerial($this->serialNo);
@@ -716,7 +729,6 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					$this->gPage->updateParentWindow();
 					
 					// 運用ログを残す
-					//$this->gOpeLog->writeUserInfo(__METHOD__, 'ブログ記事を削除しました。タイトル: ' . $name, 2100, 'ID=' . $this->entryId);
 					$eventParam = array(	M3_EVENT_HOOK_PARAM_CONTENT_TYPE	=> M3_VIEW_TYPE_BLOG,
 											M3_EVENT_HOOK_PARAM_CONTENT_ID		=> $this->entryId,
 											M3_EVENT_HOOK_PARAM_UPDATE_DT		=> date("Y/m/d H:i:s"));
@@ -850,14 +862,13 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			}
 		}
 		// カテゴリーメニューを作成
-		self::$_mainDb->getAllCategory($this->langId, $this->categoryListData);
 		$this->createCategoryMenu($this->categoryCount);
 		
 		// ユーザ定義フィールドを作成
 		$this->createUserFields($fieldInfoArray);
 		
 		// 所属ブログ
-		if (empty($useMultiBlog)){
+		if (empty($this->useMultiBlog)){
 /*			$this->tmpl->setAttribute('show_blogid_area', 'visibility', 'visible');
 			
 			$blogName = $this->getBlogName($this->blogId);
@@ -872,7 +883,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		}
 		
 		// コメント機能の設定
-		if ($useComment){
+		if ($this->useComment){
 			$this->tmpl->setAttribute('show_comment_area', 'visibility', 'visible');
 			
 			$this->tmpl->addVar("show_comment_area", "show_comment", $this->convertToCheckedString($showComment));// コメントを表示するかどうか
@@ -956,7 +967,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			$this->tmpl->addVar('_widget', 'id', $itemId);
 			
 			// ボタンの表示制御
-			if ($this->serialNo == 0){		// 未登録データのとき
+			if (empty($this->serialNo)){		// 未登録データのとき
 				// データ追加ボタン表示
 				$this->tmpl->setAttribute('add_button', 'visibility', 'visible');
 			} else {
@@ -1015,7 +1026,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			case 3:	$status = '非公開';	break;
 		}
 		// 総参照数
-		$totalViewCount = $this->gInstance->getAnalyzeManager()->getTotalContentViewCount(self::CONTENT_TYPE, $serial);
+		$totalViewCount = $this->gInstance->getAnalyzeManager()->getTotalContentViewCount(blog_mainCommonDef::VIEW_CONTENT_TYPE, $serial);
 		
 		// ユーザからの参照状況
 		$now = date("Y/m/d H:i:s");	// 現在日時
@@ -1056,9 +1067,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			'category' => $category,											// 記事カテゴリー
 			'view_count' => $totalViewCount,									// 総参照数
 			'reg_user' => $this->convertToDispString($fetchedRow['lu_name']),	// 投稿者
-			'reg_date' => $this->convertToDispDateTime($fetchedRow['be_regist_dt']),	// 投稿日時
-			'update_user' => $this->convertToDispString($fetchedRow['lu_name']),	// 更新者
-			'update_date' => $this->convertToDispDateTime($fetchedRow['be_create_dt'])	// 更新日時
+			'reg_date' => $this->convertToDispDateTime($fetchedRow['be_regist_dt'], 0/*ロングフォーマット*/, 10/*時分*/)		// 投稿日時
 		);
 		$this->tmpl->addVars('itemlist', $row);
 		$this->tmpl->parseTemplate('itemlist', 'a');
@@ -1267,5 +1276,40 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		}
 		return true;
 	}
+	/**
+	 * カテゴリーを並び順でソート
+	 *
+	 * @param array $categoryArray	ソート対象のカテゴリー
+	 * @return bool					true=成功、false=失敗
+	 */
+	function sortCategory(&$categoryArray)
+	{
+		// 重複を除く
+		$categoryArray = array_unique($categoryArray);
+		
+		// ソート情報作成
+		$this->categorySortInfo = array();
+		$categoryCount = count($this->categoryListData);
+		for ($i = 0; $i < $categoryCount; $i++){
+			$key = $this->categoryListData[$i]['bc_id'];
+			$this->categorySortInfo[$key] = $i;
+		}
+		
+		// カテゴリーをソート
+		usort($categoryArray, array($this, 'sortCategoryCompare'));
+		return true;
+	}
+	/**
+	 * カテゴリーソート用
+	 *
+	 * @param int $a		比較値
+	 * @param int $b		比較値
+	 * @return int			比較結果
+	 */
+	function sortCategoryCompare($a, $b)
+	{
+		if ($this->categorySortInfo[$a] == $this->categorySortInfo[$b]) return 0;
+		return ($this->categorySortInfo[$a] < $this->categorySortInfo[$b]) ? -1 : 1;
+	}
 }
 ?>
